@@ -784,6 +784,8 @@ gdImageStringFTEx (gdImage * im, int *brect, int fg, char *fontlist, double ptsi
 	double cos_a = cos (angle);
 	int len, i = 0, ch;
 	int x1 = 0, y1 = 0;
+	int xb = x, yb = y;
+	int yd = 0;
 	font_t *font;
 	fontkey_t fontkey;
 	char *next;
@@ -918,14 +920,15 @@ gdImageStringFTEx (gdImage * im, int *brect, int fg, char *fontlist, double ptsi
 	}
 #endif
 
+	i = 0;
 	while (*next) {
 		ch = *next;
 
 		/* carriage returns */
 		if (ch == '\r') {
 			penf.x = 0;
-			x1 = (int)(penf.x * cos_a - penf.y * sin_a + 32) / 64;
-			y1 = (int)(penf.x * sin_a + penf.y * cos_a + 32) / 64;
+			x1 = (int)(- penf.y * sin_a + 32) / 64;
+			y1 = (int)(- penf.y * cos_a + 32) / 64;
 			pen.x = pen.y = 0;
 			previous = 0;		/* clear kerning flag */
 			next++;
@@ -933,15 +936,18 @@ gdImageStringFTEx (gdImage * im, int *brect, int fg, char *fontlist, double ptsi
 		}
 		/* newlines */
 		if (ch == '\n') {
+			if (!*(++next)) break;
 			/* 2.0.13: reset penf.x. Christopher J. Grayce */
 			penf.x = 0;
 			  penf.y -= (long)(face->size->metrics.height * linespace);
 			  penf.y = (penf.y - 32) & -64;		/* round to next pixel row */
-			  x1 = (int)(penf.x * cos_a - penf.y * sin_a + 32) / 64;
-			  y1 = (int)(penf.x * sin_a + penf.y * cos_a + 32) / 64;
+			  x1 = (int)(- penf.y * sin_a + 32) / 64;
+			  y1 = (int)(- penf.y * cos_a + 32) / 64;
+			  xb = x + x1;
+			  yb = y + y1;
+			  yd = 0;
 			  pen.x = pen.y = 0;
 			  previous = 0;		/* clear kerning flag */
-			  next++;
 			  continue;
 		}
 
@@ -1055,11 +1061,17 @@ gdImageStringFTEx (gdImage * im, int *brect, int fg, char *fontlist, double ptsi
 				glyph_bbox.xMax += slot->metrics.horiAdvance;
 			}
 			if (!i) { /* if first character, init BB corner values */
+				yd = slot->metrics.height - slot->metrics.horiBearingY;
 				bbox.xMin = glyph_bbox.xMin;
 				bbox.yMin = glyph_bbox.yMin;
 				bbox.xMax = glyph_bbox.xMax;
 				bbox.yMax = glyph_bbox.yMax;
 			} else {
+				FT_Pos desc;
+
+				if ( (desc = (slot->metrics.height - slot->metrics.horiBearingY)) > yd) {
+					yd = desc;
+				}
 				if (bbox.xMin > glyph_bbox.xMin) {
 					bbox.xMin = glyph_bbox.xMin;
 				}
@@ -1088,7 +1100,7 @@ gdImageStringFTEx (gdImage * im, int *brect, int fg, char *fontlist, double ptsi
 
 			/* now, draw to our target surface */
 			bm = (FT_BitmapGlyph) image;
-			gdft_draw_bitmap(tc_cache, im, fg, bm->bitmap, x + x1 + ((pen.x + 31) >> 6) + bm->left, y - y1 + ((pen.y + 31) >> 6) - bm->top);
+			gdft_draw_bitmap(tc_cache, im, fg, bm->bitmap, x + x1 + ((pen.x + 31) >> 6) + bm->left, y + y1 + ((pen.y + 31) >> 6) - bm->top);
 		}
 
 		/* record current glyph index for kerning */
@@ -1116,25 +1128,28 @@ gdImageStringFTEx (gdImage * im, int *brect, int fg, char *fontlist, double ptsi
 		normbox.xMax = bbox.xMax - bbox.xMin;
 		normbox.yMax = bbox.yMax - bbox.yMin;
 
+		brect[0] = brect[2] = brect[4] = brect[6] = (int)  (yd * sin_a);
+		brect[1] = brect[3] = brect[5] = brect[7] = (int)(- yd * cos_a);
+
 		/* rotate bounding rectangle */
-		brect[0] = (int) (normbox.xMin * cos_a - normbox.yMin * sin_a);
-		brect[1] = (int) (normbox.xMin * sin_a + normbox.yMin * cos_a);
-		brect[2] = (int) (normbox.xMax * cos_a - normbox.yMin * sin_a);
-		brect[3] = (int) (normbox.xMax * sin_a + normbox.yMin * cos_a);
-		brect[4] = (int) (normbox.xMax * cos_a - normbox.yMax * sin_a);
-		brect[5] = (int) (normbox.xMax * sin_a + normbox.yMax * cos_a);
-		brect[6] = (int) (normbox.xMin * cos_a - normbox.yMax * sin_a);
-		brect[7] = (int) (normbox.xMin * sin_a + normbox.yMax * cos_a);
+		brect[0] += (int) (normbox.xMin * cos_a - normbox.yMin * sin_a);
+		brect[1] += (int) (normbox.xMin * sin_a + normbox.yMin * cos_a);
+		brect[2] += (int) (normbox.xMax * cos_a - normbox.yMin * sin_a);
+		brect[3] += (int) (normbox.xMax * sin_a + normbox.yMin * cos_a);
+		brect[4] += (int) (normbox.xMax * cos_a - normbox.yMax * sin_a);
+		brect[5] += (int) (normbox.xMax * sin_a + normbox.yMax * cos_a);
+		brect[6] += (int) (normbox.xMin * cos_a - normbox.yMax * sin_a);
+		brect[7] += (int) (normbox.xMin * sin_a + normbox.yMax * cos_a);
 
 		/* scale, round and offset brect */
-		brect[0] = x + gdroundupdown(brect[0], d2 > 0);
-		brect[1] = y - gdroundupdown(brect[1], d1 < 0);
-		brect[2] = x + gdroundupdown(brect[2], d1 > 0);
-		brect[3] = y - gdroundupdown(brect[3], d2 > 0);
-		brect[4] = x + gdroundupdown(brect[4], d2 < 0);
-		brect[5] = y - gdroundupdown(brect[5], d1 > 0);
-		brect[6] = x + gdroundupdown(brect[6], d1 < 0);
-		brect[7] = y - gdroundupdown(brect[7], d2 < 0);
+		brect[0] = xb + gdroundupdown(brect[0], d2 > 0);
+		brect[1] = yb - gdroundupdown(brect[1], d1 < 0);
+		brect[2] = xb + gdroundupdown(brect[2], d1 > 0);
+		brect[3] = yb - gdroundupdown(brect[3], d2 > 0);
+		brect[4] = xb + gdroundupdown(brect[4], d2 < 0);
+		brect[5] = yb - gdroundupdown(brect[5], d1 > 0);
+		brect[6] = xb + gdroundupdown(brect[6], d1 < 0);
+		brect[7] = yb - gdroundupdown(brect[7], d2 < 0);
 	}
 
 	if (tmpstr) {
