@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2007 The PHP Group                                |
+  | Copyright (c) 1997-2009 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -15,7 +15,7 @@
   | Author: Hartmut Holzgraefe  <hholzgra@php.net>                       |
   +----------------------------------------------------------------------+
 
-  $Id: mime_magic.c,v 1.42.2.5.2.6 2007/02/15 00:05:42 iliaa Exp $ 
+  $Id: mime_magic.c 272374 2008-12-31 11:17:49Z sebastian $ 
 
   This module contains a lot of stuff taken from Apache mod_mime_magic,
   so the license section is a little bit longer than usual:
@@ -1764,6 +1764,9 @@ static void mprint(union VALUETYPE *p, struct magic *m)
 		{
 			char ctimebuf[52];
 			pp = php_ctime_r((time_t *) &p->l, ctimebuf);
+			if (!pp) {
+				return;
+			}
 			if ((rt = strchr(pp, '\n')) != NULL) {
 				*rt = '\0';
 			}
