@@ -18,7 +18,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: pgsql_statement.c,v 1.31.2.12.2.15 2009/05/25 19:41:41 kalle Exp $ */
+/* $Id: pgsql_statement.c 288013 2009-09-03 22:53:25Z mbeccati $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -599,8 +599,14 @@ static int pgsql_stmt_get_col(pdo_stmt_t *stmt, int colno, char **ptr, unsigned
 					return 0;
 				} else {
 					*ptr = php_pdo_pgsql_unescape_bytea(*ptr, &tmp_len);
-					*len = tmp_len;
-					*caller_frees = 1;
+					if (!tmp_len) {
+						/* Empty string, return as empty stream */
+						*ptr = (char *)php_stream_memory_open(TEMP_STREAM_READONLY, "", 0);
+						*len = 0;
+					} else {
+						*len = tmp_len;
+						*caller_frees = 1;
+					}
 				}
 				break;
 			case PDO_PARAM_NULL:
