@@ -15,7 +15,7 @@
    | Author: Chris Schneider <cschneid@relog.ch>                          |
    +----------------------------------------------------------------------+
  */
-/* $Id: pack.c,v 1.57.2.5.2.9 2009/05/12 12:35:45 iliaa Exp $ */
+/* $Id: pack.c 287647 2009-08-24 18:40:13Z iliaa $ */
 
 #include "php.h"
 
@@ -708,15 +708,15 @@ PHP_FUNCTION(unpack)
 						buf = emalloc(len + 1);
 
 						for (ipos = opos = 0; opos < len; opos++) {
-							char c = (input[inputpos + ipos] >> nibbleshift) & 0xf;
+							char cc = (input[inputpos + ipos] >> nibbleshift) & 0xf;
 
-							if (c < 10) {
-								c += '0';
+							if (cc < 10) {
+								cc += '0';
 							} else {
-								c += 'a' - 10;
+								cc += 'a' - 10;
 							}
 
-							buf[opos] = c;
+							buf[opos] = cc;
 							nibbleshift = (nibbleshift + 4) & 7;
 
 							if (first-- == 0) {
