@@ -41,7 +41,7 @@
 #include <stdlib.h>
 #endif
 
-static const char rcsid[] = "#(@) $Id: encodings.c,v 1.4.4.1 2002/11/27 04:07:00 fmk Exp $";
+static const char rcsid[] = "#(@) $Id: encodings.c 242679 2007-09-19 00:33:43Z stas $";
 
 #include <errno.h>
 
@@ -53,17 +53,24 @@ static const char rcsid[] = "#(@) $Id: encodings.c,v 1.4.4.1 2002/11/27 04:07:00
 
 #include "encodings.h"
 
+#ifndef ICONV_CSNMAXLEN
+#define ICONV_CSNMAXLEN 64
+#endif
+
 static char* convert(const char* src, int src_len, int *new_len, const char* from_enc, const char* to_enc) {
    char* outbuf = 0;
 
    if(src && src_len && from_enc && to_enc) {
-      int outlenleft = src_len;
+      size_t outlenleft = src_len;
+      size_t inlenleft = src_len;
       int outlen = src_len;
-      int inlenleft = src_len;
-      iconv_t ic = iconv_open(to_enc, from_enc);
-      char* src_ptr = (char*)src;
+      iconv_t ic;
       char* out_ptr = 0;
 
+      if(strlen(to_enc) >= ICONV_CSNMAXLEN || strlen(from_enc) >= ICONV_CSNMAXLEN) {
+         return NULL;
+      }
+      ic = iconv_open(to_enc, from_enc);
       if(ic != (iconv_t)-1) {
          size_t st;
          outbuf = (char*)malloc(outlen + 1);
@@ -71,7 +78,7 @@ static char* convert(const char* src, int src_len, int *new_len, const char* fro
          if(outbuf) {
             out_ptr = (char*)outbuf;
             while(inlenleft) {
-               st = iconv(ic, &src_ptr, &inlenleft, &out_ptr, &outlenleft);
+               st = iconv(ic, (char**)&src, &inlenleft, &out_ptr, &outlenleft);
                if(st == -1) {
                   if(errno == E2BIG) {
                      int diff = out_ptr - outbuf;
